@@ -4,7 +4,7 @@ import csv
 import boto3
 import requests
 import hashlib
-from io import StringIO
+from io import StringIO, BytesIO
 from boto3.s3.transfer import TransferConfig
 from Crypto.Cipher import AES
 from base64 import b64encode, b64decode
@@ -281,7 +281,8 @@ def write_ram_file(f: StringIO, data: Generator, fieldnames: list, delimiter='\t
     return f
 
 
-def upload_to_s3_from_ram(content: Union[StringIO], filename: str, folder: str = 'yandex_files/', suffix: str = '.tsv'):
+def upload_to_s3_from_ram(content: Union[StringIO, BytesIO], filename: str, folder: str = 'yandex_files/',
+                          suffix: str = '.tsv'):
     if filename.startswith('/tmp/'):
         s3_filename = filename[5:]
     else:
@@ -289,8 +290,9 @@ def upload_to_s3_from_ram(content: Union[StringIO], filename: str, folder: str =
     if suffix not in s3_filename:
         s3_filename = f"{s3_filename}{suffix}"
     s3 = boto3.resource('s3')
+    body = content.getvalue().encode('utf-8') if isinstance(content, StringIO) else content.getvalue()
     s3.meta.client.put_object(Bucket=BUCKET_NAME, Key=f'{folder}{s3_filename}',
-                              Body=content.getvalue().encode('utf-8'), ACL='public-read')
+                              Body=body, ACL='public-read')
     return {
         "status": "success",
         "s3_filename": s3_filename,
